%define        messagebus_uid  25
%define        messagebus_gid  25

Name:          dbus
Version:       1.14.6
Release:       1mamba
Summary:       A message bus, used for sending messages between applications
Group:         System/Servers
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://www.freedesktop.org/wiki/Software/dbus/
Source:        http://dbus.freedesktop.org/releases/dbus/%{name}-%{version}.tar.xz
Source1:       dbus-initscript
Source2:       %{name}-session-profile.sh
Patch0:        %{name}-1.0.1-cve_2006_6107.patch
Patch1:        dbus-1.6.8-initscript-rename.patch
Patch2:        dbus-1.8.12-systemd-fix-shutdown-hangs.patch
License:       GPL
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
%if "%{stage1}" != "1"
BuildRequires: libICE-devel
BuildRequires: libSM-devel
BuildRequires: libX11-devel
%endif
BuildRequires: libaudit-devel
BuildRequires: libcap-ng-devel
BuildRequires: libdw-devel
BuildRequires: libexpat-devel
BuildRequires: libgcrypt-devel
BuildRequires: libgpg-error-devel
BuildRequires: liblzma-devel
BuildRequires: libselinux-devel
BuildRequires: systemd-devel
## AUTOBUILDREQ-END
%if "%{stage1}" != "1"
BuildRequires: libXau-devel
BuildRequires: libxcb-devel
BuildRequires: libXdmcp-devel
%endif
BuildRequires: pkgconfig >= 0.19
BuildRequires: gettext-devel
BuildRequires: libxml2-devel
BuildRequires: libxml2-utils
BuildRequires: libglib-devel
%if "%{_build}" == "%{_host}"
BuildRequires: doxygen
BuildRequires: xmlto
%endif
Requires(pre): /usr/sbin/useradd
Requires(pre): /sbin/chkconfig
Requires(pre): filesystem >= 2.2-19mamba
Requires(pre): shadow
Requires:      lib%{name} = %{?epoch:%epoch:}%{version}-%{release}
Provides:      dbus-tools
Obsoletes:     dbus-tools < 1.14.0
## *AUTOSPEC-OFF*
Obsoletes:     dbus-viewer < 1.14.0
Obsoletes:     dbus1-viewer < 1.14.0
Obsoletes:     dbus1 < 1.14.0
## *AUTOSPEC-ON*

%description
D-BUS is a message bus, used for sending messages between applications.
Conceptually, it fits somewhere in between raw sockets and CORBA in terms of complexity.

%package tools
Summary:       Tools for D-BUS
Group:         System/Tools
Requires:      lib%{name} = %{?epoch:%epoch:}%{version}-%{release}
Obsoletes:     dbus1-tools < 1.14.0

%description tools
dbus-launch: utility to start a message bus from a shell script 
dbus-monitor: debug probe to print message bus messages

%package -n lib%{name}
Summary:       Shared library for using D-Bus
Group:         System/Libraries

%description -n lib%{name}
D-Bus shared library.

%package -n lib%{name}-devel
Summary:       Devel package for %{name}
Group:         Development/Libraries
Requires:      lib%{name} = %{?epoch:%epoch:}%{version}-%{release}
Obsoletes:     dbus-devel < 1.14.0
Provides:      dbus-devel = %{?epoch:%epoch:}%{version}-%{release}
## *AUTOSPEC-OFF*
Obsoletes:     dbus1-devel < 1.14.0
Provides:      dbus1-devel = %{?epoch:%epoch:}%{version}-%{release}
## *AUTOSPEC-ON*

%description -n lib%{name}-devel
D-BUS is a message bus, used for sending messages between applications.
Conceptually, it fits somewhere in between raw sockets and CORBA in terms of complexity.
This package contains static libraries and header files need for development.

%package apidocs
Group:         Documentation
Summary:       %{name} API documentation
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}
Requires:      gtk-doc

%description apidocs
This package includes the %{name} API documentation.

%debug_package

%prep
%setup -q
%patch0 -p1 -b .cve_2006_6107
#%patch2 -p1

%build
%configure \
    --enable-dnotify \
    --enable-selinux \
	--enable-systemd \
	--enable-user-session \
    --disable-checks \
    --disable-asserts \
	--runstatedir=/run \
    --with-system-pid-file=/run/messagebus.pid \
    --with-system-socket=/run/dbus/system_bus_socket \
    --with-session-socket-dir=/tmp \
%if "%{stage1}" == "1"
   --without-x
%endif

%make
#make check

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
%makeinstall

install -d 0755 %{buildroot}%{_datadir}/dbus-1/services
install -d %{buildroot}%{_sysconfdir}/dbus-1/system.d/
install -d %{buildroot}%{_sysconfdir}/dbus-1/session.d/
install -d %{buildroot}%{_var}/lib/dbus
#[ -e %{buildroot}%{_var}/run/dbus ] && rmdir %{buildroot}%{_var}/run/dbus
#ln -s /run/dbus %{buildroot}%{_var}/run/dbus

#install -m 0755 %{S:1} %{buildroot}%{_initrddir}/messagebus
#install -D -m 0755 %{S:2} %{buildroot}%{_sysconfdir}/profile.d/dbus-session.sh

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%pre
if [ $1 -ge 1 ]; then
   %tmpfiles_create dbus.conf
   ## /var/run to /run upgrade with compatibility symlink
   #if [ -d /var/run/dbus -a ! -L /var/run/dbus -a ! -e /run/dbus ]; then
   #   mkdir /run/dbus
   #   mv /var/run/dbus/* /run/dbus
   #   rmdir /var/run/dbus
   #fi
   # add DBUS user
   /usr/sbin/groupadd messagebus -g %{messagebus_gid} &>/dev/null
   /usr/sbin/useradd -u %{messagebus_uid} -c 'DBUS user' -d /dev/null \
      -s /bin/false messagebus -g %{messagebus_gid} 2>/dev/null
   /usr/sbin/usermod messagebus -g messagebus &>/dev/null
fi
:

%post
%systemd_post %{name}
if [ $1 -ge 1 ]; then
   /sbin/ldconfig
   [ $1 -eq 1 ] && systemctl -q start dbus
   %{_bindir}/dbus-uuidgen --ensure
fi
:

%preun
# erase
%systemd_preun %{name}
if [ $1 -eq 0 ]; then
   userdel messagebus || true
   groupdel messagebus || true
fi
:

%postun
%systemd_postun %{name}
:

%posttrans
# clean old sysv broken links
find /etc/rc[0-6].d/ -type l -xtype l -exec rm -f {} \;   
:

%post -n lib%{name} -p /sbin/ldconfig
%postun -n lib%{name} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%dir %{_sysconfdir}/dbus-1
%config %{_sysconfdir}/dbus-1/session.conf
%config %{_sysconfdir}/dbus-1/system.conf
%dir %{_sysconfdir}/dbus-1/system.d/
%dir %{_sysconfdir}/dbus-1/session.d/
#%{_sysconfdir}/profile.d/dbus-session.sh
%{_bindir}/dbus-cleanup-sockets
%{_bindir}/dbus-daemon
%{_bindir}/dbus-launch
%{_bindir}/dbus-monitor
%{_bindir}/dbus-run-session
%{_bindir}/dbus-send
%{_bindir}/dbus-test-tool
%{_bindir}/dbus-update-activation-environment
%{_bindir}/dbus-uuidgen
%attr(4750,root,messagebus) %{_libexecdir}/dbus-daemon-launch-helper
%{_prefix}/lib/sysusers.d/dbus.conf
%{_prefix}/lib/tmpfiles.d/dbus.conf
%{_unitdir}/dbus.service
%{_unitdir}/dbus.socket
#%{_unitdir}/dbus.target.wants/dbus.socket
%{_unitdir}/multi-user.target.wants/dbus.service
%{_unitdir}/sockets.target.wants/dbus.socket
%{_userunitdir}/dbus.service
%{_userunitdir}/dbus.socket
%{_userunitdir}/sockets.target.wants/dbus.socket
%dir %{_datadir}/dbus-1
%dir %{_datadir}/dbus-1/services
%{_datadir}/dbus-1/session.conf
%{_datadir}/dbus-1/system.conf
%dir %{_datadir}/xml/dbus-1
%{_datadir}/xml/dbus-1/*.dtd
%{_datadir}/xml/dbus-1/catalog.xml
#%dir %{_var}/run/dbus
%dir %{_var}/lib/dbus
%{_mandir}/man1/dbus-cleanup-sockets.*
%{_mandir}/man1/dbus-daemon.*
%{_mandir}/man1/dbus-run-session.1.gz
%{_mandir}/man1/dbus-send.*
%{_mandir}/man1/dbus-uuidgen.*
%{_mandir}/man1/dbus-launch.*
%{_mandir}/man1/dbus-monitor.*
%{_mandir}/man1/dbus-test-tool.1*
%{_mandir}/man1/dbus-update-activation-environment.1*

%files -n lib%{name}
%defattr(-,root,root)
%{_libdir}/libdbus-1.so.*
%doc AUTHORS COPYING

%files -n lib%{name}-devel
%defattr(-,root,root)
%{_libdir}/libdbus-1.so
%{_libdir}/libdbus-1.a
%{_libdir}/pkgconfig/*.pc
%dir %{_libdir}/dbus-1.0/include/dbus
%{_libdir}/dbus-1.0/include/dbus/dbus-arch-deps.h
%dir %{_includedir}/dbus-1.0/dbus
%{_includedir}/dbus-1.0/dbus/*
%dir %{_libdir}/cmake/DBus1
%{_libdir}/cmake/DBus1/DBus1Config*.cmake
#%doc ChangeLog NEWS README

%files apidocs
%defattr(-,root,root)
%dir %{_docdir}/dbus
%{_docdir}/dbus/*

%changelog
* Thu Feb 09 2023 Automatic Build System <autodist@mambasoft.it> 1.14.6-1mamba
- automatic version update by autodist

* Thu Oct 06 2022 Automatic Build System <autodist@mambasoft.it> 1.14.4-1mamba
- automatic version update by autodist

* Wed Sep 28 2022 Automatic Build System <autodist@mambasoft.it> 1.14.2-1mamba
- automatic version update by autodist

* Fri Mar 04 2022 Automatic Build System <autodist@mambasoft.it> 1.14.0-1mamba
- automatic version update by autodist

* Sun Oct 06 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 1.13.8-4mamba
- add Requires(pre): shadow to fix dbus-daemon-launch-helper permissions on live media

* Sun Mar 17 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 1.13.8-3mamba
- remove legacy /var/run/dbus symlink, require filesystem-2.2-19mamba for /run  switch

* Tue Mar 05 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 1.13.8-2mamba
- remove profile.d/dbus-session.sh script; DBUS variables are exported by pam_systemd

* Wed Feb 20 2019 Silvan Calarco <silvan.calarco@mambasoft.it> 1.13.8-1mamba
- update to 1.13.8
- configured with --enable-user-session

* Thu Mar 29 2018 Silvan Calarco <silvan.calarco@mambasoft.it> 1.13.2-1mamba
- update to 1.13.2
- move /var/run to /run

* Tue Mar 06 2018 Automatic Build System <autodist@mambasoft.it> 1.12.6-1mamba
- automatic version update by autodist

* Sat Feb 10 2018 Automatic Build System <autodist@mambasoft.it> 1.12.4-1mamba
- automatic version update by autodist

* Sun Dec 24 2017 Automatic Build System <autodist@mambasoft.it> 1.12.2-1mamba
- automatic version update by autodist

* Tue Oct 24 2017 Automatic Build System <autodist@mambasoft.it> 1.10.24-1mamba
- automatic version update by autodist

* Tue Aug 15 2017 Silvan Calarco <silvan.calarco@mambasoft.it> 1.10.22-1mamba
- update to 1.10.22

* Sat Jan 10 2015 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.14-1mamba
- update to 1.8.14
- remove previous patch apparently not needed anymore with systemd 218

* Fri Dec 05 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.8-2mamba
- patch systemd service file to fix shutdown hang (http://superuser.com/questions/767414/why-does-systemd-hang-during-reboot)
- remove old initscript and complete systemd migration

* Sat Sep 20 2014 Automatic Build System <autodist@mambasoft.it> 1.8.8-1mamba
- automatic version update by autodist

* Sat Jul 12 2014 Automatic Build System <autodist@mambasoft.it> 1.8.6-1mamba
- automatic version update by autodist

* Sat Jun 14 2014 Automatic Build System <autodist@mambasoft.it> 1.8.4-1mamba
- automatic version update by autodist

* Wed May 14 2014 Automatic Build System <autodist@mambasoft.it> 1.8.2-1mamba
- automatic version update by autodist

* Tue Feb 11 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 1.8.0-2mamba
- docs moved to apidocs subpackage

* Sat Jan 25 2014 Automatic Build System <autodist@mambasoft.it> 1.8.0-1mamba
- automatic version update by autodist

* Thu Oct 10 2013 Automatic Build System <autodist@mambasoft.it> 1.7.6-1mamba
- automatic update by autodist

* Sun Jun 16 2013 Automatic Build System <autodist@mambasoft.it> 1.7.4-1mamba
- automatic version update by autodist

* Sun May 19 2013 Automatic Build System <autodist@mambasoft.it> 1.7.2-1mamba
- automatic update by autodist

* Tue Apr 02 2013 Automatic Build System <autodist@mambasoft.it> 1.7.0-1mamba
- automatic version update by autodist

* Fri Mar 29 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 1.6.8-3mamba
- rename initscript from messagebus to dbus for systemd smooth compatibility

* Sun Mar 17 2013 Silvan Calarco <silvan.calarco@mambasoft.it> 1.6.8-2mamba
- rebuilt with systemd support

* Wed Oct 10 2012 Automatic Build System <autodist@mambasoft.it> 1.6.8-1mamba
- automatic version update by autodist

* Tue Jul 31 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 1.6.4-1mamba
- update to 1.6.4

* Thu May 03 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 1.4.20-1mamba
- update to 1.4.20
- more reliable check for existing dbus-session process in /etc/profile.d/dbus-session.sh

* Sun Feb 19 2012 Silvan Calarco <silvan.calarco@mambasoft.it> 1.4.16-1mamba
- update to 1.4.16
- added /etc/profile.d script to export DBUS session variables

* Sat Jul 30 2011 Silvan Calarco <silvan.calarco@mambasoft.it> 1.4.14-1mamba
- update to 1.4.14

* Tue Feb 22 2011 Automatic Build System <autodist@mambasoft.it> 1.4.6-1mamba
- automatic update by autodist

* Wed Dec 22 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 1.4.1-1mamba
- update to 1.4.1

* Wed Oct 06 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 1.4.0-2mamba
- change socket name to more standard /var/run/dbus/system_bus_socket

* Thu Sep 16 2010 Automatic Build System <autodist@mambasoft.it> 1.4.0-1mamba
- automatic update by autodist

* Sat Jun 26 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 1.2.24-1mamba
- update to 1.2.24

* Fri Jul 17 2009 Automatic Build System <autodist@mambasoft.it> 1.2.16-1mamba
- automatic update by autodist

* Fri May 08 2009 Automatic Build System <autodist@mambasoft.it> 1.2.14-1mamba
- automatic update by autodist

* Fri Apr 10 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 1.2.12-3mamba
- remove dbus-tools package

* Thu Apr 09 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 1.2.12-2mamba
- sed suid permissions for dbus-daemon-launch-helper and moved from libdbus-devel to dbus package
- install upstream iniscript

* Thu Jan 08 2009 Silvan Calarco <silvan.calarco@mambasoft.it> 1.2.12-1mamba
- automatic update by autodist

* Fri Nov 14 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 1.2.4-1mamba
- update to 1.2.4

* Fri Jun 13 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 1.1.20-1mamba
- update to 1.1.20

* Fri Mar 07 2008 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.3-1mamba
- update to 1.0.3

* Fri Dec 28 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.2-2mamba
- initscript: start sooner in rc init sequence (15) and stop later (80)

* Sat Apr 07 2007 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.2-1mamba
- update to version 1.0.2 by autospec
- obsolete dbus1 packages

* Mon Apr 02 2007 Davide Madrisan <davide.madrisan@gmail.com> 1.0.1-2mamba
- fixed security issue CVE-2006-6107
- added build requirements for Xorg7 and libexpat-devel

* Thu Nov 23 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 1.0.1-1qilnx
- update to version 1.0.1 by autospec

* Thu Nov 02 2006 Davide Madrisan <davide.madrisan@qilinux.it> 0.94-3qilnx
- run make check
- generates a universally unique machine ID in the %%post script
- shared libraries moved to the new lib%{name} package

* Wed Oct 25 2006 Davide Madrisan <davide.madrisan@qilinux.it> 0.94-2qilnx
- rebuilt for QiLinux
- added build requirement for libselinux

* Tue Oct 24 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 0.94-1qilnx
- update to version 0.94 by autospec

* Tue Oct 24 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 0.93-1qilnx
- update to version 0.93 by autospec
- removed bootstrap handling because Qt, Glib and Python bindings are no longer
  distributed with this package

* Fri Apr 28 2006 Davide Madrisan <davide.madrisan@qilinux.it> 0.50-5qilnx
- use the rpm macro %%pyver to get the python version
- added some missing build requirements

* Wed Mar 01 2006 Stefano Cotta Ramusino <stefano.cotta@qilinux.it> 0.50-4qilnx
- dbus-qt and dbus-viewer subpackages excluded from bootstrap compilation
- added PreReq

* Mon Feb 06 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 0.50-3qilnx
- don't restart dbus on update

* Thu Feb 02 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 0.50-2qilnx
- added package d-bus tools (depends on libX11)

* Fri Jan 27 2006 Silvan Calarco <silvan.calarco@mambasoft.it> 0.50-1qilnx
- update to version 0.50 by autospec

* Sat Sep 03 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 0.36.2-1qilnx
- update to version 0.36.2 by autospec

* Wed Aug 24 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 0.36-1qilnx
- update to version 0.36 by autospec
- added subpackage dbus-viewer

* Mon Aug 08 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 0.35.2-1qilnx
- update to version 0.35.2 by autospec

* Tue Jul 19 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 0.34-4qilnx
- other fixes to pre/post scripts

* Mon Jul 18 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 0.34-3qilnx
- fixed pre/post scripts

* Fri Jul 15 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 0.34-2qilnx
- added initscript and service automatic configuration on install

* Thu Jul 14 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 0.34-1qilnx
- update to version 0.34 by autospec

* Sat Jun 04 2005 Silvan Calarco <silvan.calarco@mambasoft.it> 0.33-1qilnx
- package created by autospec
